import {select,csv,scaleTime,scaleLinear,
       axisBottom,axisLeft,extent,
       nest,
       descending,
       schemeCategory10,
       scaleOrdinal
       } from 'd3';

import {lineChart} from './lineChart';
import {colorLegend} from './colorLegend';

import {loadProcessData,parseYear} from './loadProcessData';

const svg= select('svg');
const width= +svg.attr('width');
const height= +svg.attr('height');
const lineChartG= svg.append('g');
const colorLegendG= svg.append('g');

let data=[];

let selectedYear= 2019;
  const setSelectedYear= year =>{
  	selectedYear= year;
    render(data);
  }

const render= data=>{

  const title='Population over Time by Region';
  const margin={top:80,right:260,bottom:85,left:120};
  
  const yLabel='Population';
  const xLabel='Time';
  const colorValue= d=> d.name;
  const colorScale= scaleOrdinal(schemeCategory10);
  const lastYValue= d => yValue(d.values[d.values.length-1]);
  const spacing= 59;
  const circleRadius= 11;
  
  const xValue= d=>d.year;
  const yValue= d=>d.population;
  
  const nested= nest()
  	.key(colorValue)
  	.entries(data)
  	.sort((a,b)=>
          descending(lastYValue(a),lastYValue(b))
         );
  
  colorScale.domain(nested.map(d=> d.key));
  
  const g= svg.append('g')
  					.attr('transform',`translate(${margin.left},${margin.top})`);
  
  lineChartG.call(lineChart,{
        xValue,
        yValue,
    		colorValue,
    		colorScale,
         margin,
         width,
         height,
         data,
         yLabel,
         xLabel,
    		 nested,
    		 selectedYear,
    		 setSelectedYear
  });
  
  colorLegendG
  	.attr('transform',`translate(${width-240},105)`)
    .call(colorLegend,{
    colorScale,
    spacing,
    circleRadius
  });
  
  g.append('text')
  			.attr('class','title')
  			.attr('y',-20)
  			.text(title);
}



loadProcessData()
  .then( (loadData)=>{
		data= loadData;
  	render(data);
  // console.log(data);
})

