import {select,csv,scaleTime,scaleLinear,
       axisBottom,axisLeft,extent,
       format,
      	line,
        nest,
        curveBasis,
        linePath,
        mouse
       } from 'd3';

import {parseYear} from './loadProcessData';

export const lineChart= (selection,props)=>{
  const {xValue,
        yValue,
    		colorValue,
    		colorScale,
         margin,
         width,
         height,
         data,
         yLabel,
         xLabel,
    		 nested,
         selectedYear,
         setSelectedYear
        }=props;
  
  const innerHeight= height -margin.top-margin.bottom;
  const innerWidth= width- margin.left- margin.right;
 
  const g= selection.selectAll('.container').data([null]);
  const gEnter= g.enter()
  				.append('g')
  				.attr('class','container');
  gEnter.merge(g)
  	.attr('transform',`translate(${margin.left},${margin.top})`);
  
  const xScale= scaleTime()
                    .domain(extent(data,xValue))
                    .range([0,innerWidth]);
                    // .nice();	
  const yScale= scaleLinear()
  								.domain(extent(data,yValue))
  								.range([innerHeight,0])
  								.nice();
  const xAxis= axisBottom(xScale)
  							.tickSize(innerHeight)
  							.tickPadding(13);
  
  const yAxisFormat= num =>
  	format('.2s')(num)
  	.replace('.0','')
  	.replace('G','B');
  
  const yAxis= axisLeft(yScale)
  								.tickSize(-innerWidth)
  								.tickPadding(15)
  								.tickFormat(yAxisFormat);
  
  const yAxisG= gEnter
  				.append('g')
  				.attr('class','y-axis');
  const yG= g.select('.y-axis');
  
  yAxisG.merge(yG)
  	.call(yAxis)
  	.selectAll('.domain').remove();
  
  yAxisG.append('text')
  	.attr('fill','black')
  	.attr('class','label')
  	.attr('transform','rotate(-90)')
  	.attr('y',-80)
  	.attr('x',-innerHeight/2)
  	.attr('text-anchor','middle')
  	.text(yLabel);
  
  const xAxisG= gEnter
  				.append('g')
  				.attr('class','x-axis');
  const xG= g.select('x-axis');
  xAxisG.merge(xG)
  	.call(xAxis)
  	.selectAll('.domain').remove();
  
  xAxisG.append('text')
  	.attr('fill','black')
  	.attr('class','label')
  	.attr('x',innerWidth/2)
  	.attr('y',innerHeight+80)
  	.text(xLabel);
  
  const lineGenerator= line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
  const linePaths= g.merge(gEnter)
  	.selectAll('.lineP').data(nested);
  
  linePaths.enter().append('path')
  	.attr('class','lineP')
  	.merge(linePaths)
  	.attr('d',d => lineGenerator(d.values))
  	.attr('stroke',d=> colorScale(d.key));
  
  const selectedYearDate= parseYear(selectedYear);
  
  gEnter.append('line')
  	.attr('class','line-selected')
  	.attr('y1',0)
  	.merge(g.select('.line-selected'))
  	.attr('y2',innerHeight)
  	.attr('x1',xScale(selectedYearDate))
 		.attr('x2',xScale(selectedYearDate));
  
  
  gEnter
    .append('rect')
  	.attr('fill','none')
		.attr('class','mouse-event')
  	.attr('pointer-events','all')
  	.merge(g.select('.mouse-event'))
  		.attr('width',innerWidth)
  		.attr('height',innerHeight)
  		.on('mousemove', function(){
  			const x= mouse(this)[0];
    		const xHover= xScale.invert(x);
    		setSelectedYear(xHover.getFullYear());
  })
  
};